package com.cardiff.wylTest;

import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.mockito.Mockito.*;

import com.cardiff.client_project.HealthCareApplication;

import com.cardiff.client_project.controller.admin.SuperAdminController;
import com.cardiff.client_project.pojo.dto.SelectDTO;
import com.cardiff.client_project.service.SuperAdminService;
import com.cardiff.client_project.utils.Result;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.InjectMocks;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;



@ExtendWith(MockitoExtension.class)
@SpringBootTest(classes = HealthCareApplication.class)
public class ComponentJuintTest {

    @Mock
    private SuperAdminService superAdminService;

    @InjectMocks
    private SuperAdminController superAdminController;

    private MockMvc mockMvc;
    private ObjectMapper objectMapper;

    @BeforeEach
    public void setUp() {
        mockMvc = MockMvcBuilders.standaloneSetup(superAdminController).build();
        objectMapper = new ObjectMapper();
    }

    @Test
    public void testSelectByItem() throws Exception {
        SelectDTO selectDTO = new SelectDTO();
        selectDTO.setName("26497@qq.com");
        selectDTO.setPhone("111");
        selectDTO.setStatus(1);

        // Mocking the service call
        Result mockResult = new Result(200, "success");
        when(superAdminService.selectByItem(selectDTO)).thenReturn(mockResult);
        // Perform the HTTP request
        System.out.println(mockResult.getMsg());
        mockMvc.perform(post("/superAdmin/select")
                        .contentType("application/json")
                        .content(objectMapper.writeValueAsString(selectDTO)))
                .andExpect(status().isOk())
                .andExpect(jsonPath("$.msg").value("success"));
    }
}
